@@ -14,7 +14,7 @@
 
 #define XSIMD_VERSION_MAJOR 12
 #define XSIMD_VERSION_MINOR 1
-#define XSIMD_VERSION_PATCH 0
+#define XSIMD_VERSION_PATCH 1
 
 /**
  * high level free functions
@@ -305,9 +305,20 @@
  * Set to 1 if AVX512VNNI is available at compile-time, to 0 otherwise.
  */
 #ifdef __AVX512VNNI__
-#define XSIMD_WITH_AVX512VNNI XSIMD_WITH_AVX512F
+
+#if XSIMD_WITH_AVX512_VBMI
+#define XSIMD_WITH_AVX512VNNI_AVX512VBMI XSIMD_WITH_AVX512F
+#define XSIMD_WITH_AVX512VNNI_AVX512BW XSIMD_WITH_AVX512F
 #else
-#define XSIMD_WITH_AVX512VNNI 0
+#define XSIMD_WITH_AVX512VNNI_AVX512VBMI 0
+#define XSIMD_WITH_AVX512VNNI_AVX512BW XSIMD_WITH_AVX512F
+#endif
+
+#else
+
+#define XSIMD_WITH_AVX512VNNI_AVX512VBMI 0
+#define XSIMD_WITH_AVX512VNNI_AVX512BW 0
+
 #endif
 
 #ifdef __ARM_NEON
@@ -434,6 +445,7 @@
 #endif
 
 #if !XSIMD_WITH_SSE2 && !XSIMD_WITH_SSE3 && !XSIMD_WITH_SSSE3 && !XSIMD_WITH_SSE4_1 && !XSIMD_WITH_SSE4_2 && !XSIMD_WITH_AVX && !XSIMD_WITH_AVX2 && !XSIMD_WITH_AVXVNNI && !XSIMD_WITH_FMA3_SSE && !XSIMD_WITH_FMA4 && !XSIMD_WITH_FMA3_AVX && !XSIMD_WITH_FMA3_AVX2 && !XSIMD_WITH_AVX512F && !XSIMD_WITH_AVX512CD && !XSIMD_WITH_AVX512DQ && !XSIMD_WITH_AVX512BW && !XSIMD_WITH_AVX512ER && !XSIMD_WITH_AVX512PF && !XSIMD_WITH_AVX512IFMA && !XSIMD_WITH_AVX512VBMI && !XSIMD_WITH_NEON && !XSIMD_WITH_NEON64 && !XSIMD_WITH_SVE && !XSIMD_WITH_RVV && !XSIMD_WITH_WASM
+#define XSIMD_NO_SUPPORTED_ARCHITECTURE
 #endif
 
 #endif
